@@ -27,8 +27,8 @@
 #include <QTimeZone>
 #include "oobe.h"
 
-Oobe::Oobe(MProcess &mproc, Ui::MeInstall &ui, QWidget *parent, const QSettings &appConf, bool oem, bool modeOOBE)
-    : QObject(parent), proc(mproc), gui(ui), master(parent), oem(oem), online(modeOOBE)
+Oobe::Oobe(MProcess &mproc, Ui::MeInstall &ui, QWidget *parent, const QSettings &appConf)
+    : QObject(parent), proc(mproc), gui(ui), master(parent)
 {
     gui.textComputerName->setText(appConf.value("DEFAULT_HOSTNAME").toString());
     enableServices = appConf.value("ENABLE_SERVICES").toStringList();
@@ -51,7 +51,7 @@ Oobe::Oobe(MProcess &mproc, Ui::MeInstall &ui, QWidget *parent, const QSettings
             "-mindepth", "2", "-type", "f", "-printf", "%P\\n"}, nullptr, true);
     timeZones = proc.readOutLines();
     gui.comboTimeArea->clear();
-    for (const QString &zone : qAsConst(timeZones)) {
+    for (const QString &zone : timeZones) {
         const QString &area = zone.section('/', 0, 0);
         if (gui.comboTimeArea->findData(QVariant(area)) < 0) {
             QString text(area);
@@ -93,7 +93,7 @@ Oobe::Oobe(MProcess &mproc, Ui::MeInstall &ui, QWidget *parent, const QSettings
         // test if there's another user other than demo in /home,
         // indicating a possible snapshot or complicated live-usb
         haveSnapshotUserAccounts = proc.shell("/bin/ls -1 /home"
-            " | grep -Ev '^(lost\\+found|demo|snapshot)$' | grep -q '[a-zA-Z0-9]'");
+            " | grep -Ev '(lost\\+found|demo|snapshot)' | grep -q [a-zA-Z0-9]");
         qDebug() << "check for possible snapshot:" << haveSnapshotUserAccounts;
     }
 
@@ -194,36 +194,32 @@ void Oobe::enable()
     proc.setChRoot();
 }
 
-void Oobe::process()
+bool Oobe::process()
 {
-    if (!oem) {
-        if (!online) proc.setChRoot("/mnt/antiX");
-
-        QTreeWidgetItemIterator it(gui.treeServices);
-        for (; *it; ++it) {
-            if ((*it)->parent()) setService((*it)->text(0), (*it)->checkState(0) == Qt::Checked);
-        }
-        if (haveSamba) {
-            const bool enable = gui.checkSamba->isChecked();
-            setService("smbd", enable);
-            setService("nmbd", enable);
-            setService("samba-ad-dc", enable);
-        }
-        proc.setChRoot();
-        setComputerName();
-        setLocale();
+    if (!online) proc.setChRoot("/mnt/antiX");
+    QTreeWidgetItemIterator it(gui.treeServices);
+    for (; *it; ++it) {
+        if ((*it)->parent()) setService((*it)->text(0), (*it)->checkState(0) == Qt::Checked);
     }
-    if (haveSnapshotUserAccounts || oem) { // skip user account creation
+    if (haveSamba) {
+        const bool enable = gui.checkSamba->isChecked();
+        setService("smbd", enable);
+        setService("nmbd", enable);
+        setService("samba-ad-dc", enable);
+    }
+    proc.setChRoot();
+
+    if (!setComputerName()) return false;
+    setLocale();
+    if (haveSnapshotUserAccounts) { // skip user account creation
         proc.exec("rsync", {"-a", "/home/", "/mnt/antiX/home/",
             "--exclude", ".cache", "--exclude", ".gvfs", "--exclude", ".dbus", "--exclude", ".Xauthority",
             "--exclude", ".ICEauthority", "--exclude", ".config/session"});
     } else {
-        setUserInfo();
-    }
-    if (online) {
-        proc.shell("sed -i 's/nosplash\\b/splash/g' /boot/grub/grub.cfg");
-        proc.exec("update-rc.d", {"oobe", "disable"});
+        if (!setUserInfo()) return false;
     }
+    if (online) proc.exec("update-rc.d", {"oobe", "disable"});
+    return true;
 }
 
 /* Services */
@@ -237,7 +233,7 @@ void Oobe::buildServiceList()
     QSettings services_desc("/usr/share/gazelle-installer-data/services.list", QSettings::NativeFormat);
     services_desc.setIniCodec("UTF-8");
 
-    for (const QString &service : qAsConst(enableServices)) {
+    for (const QString &service : enableServices) {
         const QString &lang = QLocale::system().bcp47Name().toLower();
         QString lang_str = (lang == "en")? "" : "_" + lang;
         QStringList list = services_desc.value(service + lang_str).toStringList();
@@ -288,7 +284,7 @@ void Oobe::setService(const QString &service, bool enabled)
 {
     qDebug() << "Set service:" << service << enabled;
     if (enabled) {
-        proc.exec("update-rc.d", {service, "defaults"});
+        proc.exec("update-rc.d", {service, " defaults"});
         if (containsSystemD) proc.exec("systemctl", {"enable", service});
         if (containsRunit) {
             QFile::remove(proc.chRoot + "/etc/sv/" + service + "/down");
@@ -306,7 +302,7 @@ void Oobe::setService(const QString &service, bool enabled)
         if (containsRunit) {
             if (!QFile::exists(proc.chRoot + "/etc/sv/" + service)) {
                 proc.mkpath(proc.chRoot + "/etc/sv/" + service);
-                proc.exec("unlink", {"/etc/sv/" + service, "/etc/service/"});
+                proc.exec("ln", {"-fs", "/etc/sv/" + service, "/etc/service/"});
             }
             proc.exec("touch", {"/etc/sv/" + service + "/down"});
         }
@@ -348,7 +344,7 @@ QWidget *Oobe::validateComputerName()
 }
 
 // set the computer name, can not be rerun
-void Oobe::setComputerName()
+bool Oobe::setComputerName()
 {
     QString etcpath = online ? "/etc" : "/mnt/antiX/etc";
     if (haveSamba) {
@@ -369,6 +365,7 @@ void Oobe::setComputerName()
     proc.shell("sed -i 's/.*send host-name.*/send host-name \""
         + compname + "\";/g' " + etcpath + "/dhcp/dhclient.conf");
     proc.shell("echo \"" + compname + "\" | cat > " + etcpath + "/defaultdomain");
+    return true;
 }
 
 // return 0 = success, 1 = bad area, 2 = bad zone
@@ -386,14 +383,16 @@ int Oobe::selectTimeZone(const QString &zone)
 
 void Oobe::setLocale()
 {
-    proc.log(__PRETTY_FUNCTION__, MProcess::Section);
+    proc.log(__PRETTY_FUNCTION__);
+    QString cmd2;
+    QString cmd;
 
     //locale
-    qDebug() << "Update locale";
-    QString cmd;
     if (!online) cmd = "chroot /mnt/antiX ";
     cmd += QString("/usr/sbin/update-locale \"LANG=%1\"").arg(gui.comboLocale->currentData().toString());
+    qDebug() << "Update locale";
     proc.shell(cmd);
+    cmd = QString("Language=%1").arg(gui.comboLocale->currentData().toString());
     const QString &selTimeZone = gui.comboTimeZone->currentData().toString();
 
     // /etc/localtime is either a file or a symlink to a file in /usr/share/zoneinfo. Use the one selected by the user.
@@ -414,8 +413,8 @@ void Oobe::setLocale()
     }
     proc.exec("hwclock", {"--hctosys"});
     if (!online) {
-        proc.exec("/bin/cp", {"-f", "/etc/adjtime", "/mnt/antiX/etc/"});
-        proc.exec("/bin/cp", {"-f", "/etc/default/rcS", "/mnt/antiX/etc/default"});
+        proc.exec("/bin/cp", {"-f /etc/adjtime", "/mnt/antiX/etc/"});
+        proc.exec("/bin/cp", {"-f /etc/default/rcS", "/mnt/antiX/etc/default"});
     }
 
     // Set clock format
@@ -431,10 +430,6 @@ void Oobe::setLocale()
         proc.shell("sed -i '/use24hFormat=/c\\use24hFormat=0' /home/demo/.config/plasma-org.kde.plasma.desktop-appletsrc");
         proc.shell("sed -i '/use24hFormat=/c\\use24hFormat=0' " + skelpath + "/.config/plasma-org.kde.plasma.desktop-appletsrc");
 
-        //mx fluxbox
-        proc.shell("sed -i '/time1_format/c\\time1_format=%l:%M' " + skelpath + "/.config/tint2/tint2rc");
-        proc.shell("sed -i '/time1_format/c\\time1_format=%l:%M' /home/demo/.config/tint2/tint2rc");
-
         //antix systems
         proc.shell("sed -i 's/%H:%M/%l:%M/g' " + skelpath + "/.icewm/preferences");
         proc.shell("sed -i 's/%k:%M/%l:%M/g' " + skelpath + "/.fluxbox/init");
@@ -450,10 +445,6 @@ void Oobe::setLocale()
         proc.shell("sed -i '/use24hFormat=/c\\use24hFormat=2' /home/demo/.config/plasma-org.kde.plasma.desktop-appletsrc");
         proc.shell("sed -i '/use24hFormat=/c\\use24hFormat=2' " + skelpath + "/.config/plasma-org.kde.plasma.desktop-appletsrc");
 
-        //mx fluxbox
-        proc.shell("sed -i '/time1_format/c\\time1_format=%H:%M' " + skelpath + "/.config/tint2/tint2rc");
-        proc.shell("sed -i '/time1_format/c\\time1_format=%H:%M' /home/demo/.config/tint2/tint2rc");
-
         //antix systems
         proc.shell("sed -i 's/%H:%M/%H:%M/g' " + skelpath + "/.icewm/preferences");
         proc.shell("sed -i 's/%k:%M/%k:%M/g' " + skelpath + "/.fluxbox/init");
@@ -501,7 +492,7 @@ QWidget *Oobe::validateUserInfo(bool automatic)
 }
 
 // setup the user, cannot be rerun
-void Oobe::setUserInfo()
+bool Oobe::setUserInfo()
 {
     // set the user passwords first
     bool ok = true;
@@ -521,7 +512,8 @@ void Oobe::setUserInfo()
     }
     if (ok && !userinfo.isEmpty()) ok = proc.exec("chpasswd", {}, &userinfo);
     if (!ok) {
-        throw QT_TR_NOOP("Failed to set user account passwords.");
+        failure = tr("Failed to set user account passwords.");
+        return false;
     }
     proc.setChRoot();
 
@@ -540,11 +532,13 @@ void Oobe::setUserInfo()
                 ok = proc.exec("/bin/mv", cargs);
             }
             if (!ok) {
-                throw QT_TR_NOOP("Failed to save old home directory.");
+                failure = tr("Failed to save old home directory.");
+                return false;
             }
         } else if (gui.radioOldHomeDelete->isChecked()) {
             if (!proc.exec("/bin/rm", {"-rf", dpath})) {
-                throw QT_TR_NOOP("Failed to delete old home directory.");
+                failure = tr("Failed to delete old home directory.");
+                return false;
             }
         }
         proc.exec("/bin/sync"); // The sync(2) system call will block the GUI.
@@ -565,11 +559,13 @@ void Oobe::setUserInfo()
         // Copy skel to demo, unless demo folder exists in remastered linuxfs.
         if (!remasteredDemo) {
             if (!proc.exec("/bin/cp", {"-a", skelpath, dpath})) {
-                throw QT_TR_NOOP("Sorry, failed to create user directory.");
+                failure = tr("Sorry, failed to create user directory.");
+                return false;
             }
         } else { // still rename the demo directory even if remastered demo home folder is detected
             if (!proc.exec("/bin/mv", {"-f", rootpath + "/home/demo", dpath})) {
-                throw QT_TR_NOOP("Sorry, failed to name user directory.");
+                failure = tr("Sorry, failed to name user directory.");
+                return false;
             }
         }
     }
@@ -604,7 +600,8 @@ void Oobe::setUserInfo()
 
     // fix the ownership, demo=newuser
     if (!proc.exec("chown", {"-R", "demo:demo", dpath})) {
-        throw QT_TR_NOOP("Sorry, failed to set ownership of user directory.");
+        failure = tr("Sorry, failed to set ownership of user directory.");
+        return false;
     }
 
     // change in files
@@ -613,26 +610,23 @@ void Oobe::setUserInfo()
     replaceStringInFile("demo", username, rootpath + "/etc/passwd");
     replaceStringInFile("demo", username, rootpath + "/etc/shadow");
     replaceStringInFile("demo", username, rootpath + "/etc/slim.conf");
-    replaceStringInFile("demo", username, rootpath + "/etc/slimski.local.conf");
     replaceStringInFile("demo", username, rootpath + "/etc/lightdm/lightdm.conf");
     replaceStringInFile("demo", username, rootpath + "/home/*/.gtkrc-2.0");
     replaceStringInFile("demo", username, rootpath + "/root/.gtkrc-2.0");
     if (gui.checkAutoLogin->isChecked()) {
         replaceStringInFile("#auto_login", "auto_login", rootpath + "/etc/slim.conf");
         replaceStringInFile("#default_user ", "default_user ", rootpath + "/etc/slim.conf");
-        replaceStringInFile("#autologin_enabled", "autologin_enabled", rootpath + "/etc/slimski.local.conf");
-        replaceStringInFile("#default_user ", "default_user ", rootpath + "/etc/slimski.local.conf");
         replaceStringInFile("User=", "User=" + username, rootpath + "/etc/sddm.conf");
     }
     else {
         replaceStringInFile("auto_login", "#auto_login", rootpath + "/etc/slim.conf");
         replaceStringInFile("default_user ", "#default_user ", rootpath + "/etc/slim.conf");
-        replaceStringInFile("autologin_enabled", "#autologin_enabled", rootpath + "/etc/slimski.local.conf");
-        replaceStringInFile("default_user ", "#default_user ", rootpath + "/etc/slimski.local.conf");
         replaceStringInFile("autologin-user=", "#autologin-user=", rootpath + "/etc/lightdm/lightdm.conf");
         replaceStringInFile("User=.*", "User=", rootpath + "/etc/sddm.conf");
     }
     proc.exec("touch", {rootpath + "/var/mail/" + username});
+
+    return true;
 }
 
 void Oobe::resetBlueman()
@@ -655,7 +649,7 @@ void Oobe::timeAreaIndexChanged(int index)
     if (index < 0 || index >= gui.comboTimeArea->count()) return;
     const QString &area = gui.comboTimeArea->itemData(index).toString();
     gui.comboTimeZone->clear();
-    for (const QString &zone : qAsConst(timeZones)) {
+    for (const QString &zone : timeZones) {
         if (zone.startsWith(area)) {
             QString text(QString(zone).section('/', 1));
             text.replace('_', ' ');
